/**
** This software is distributed under the terms of the General Public License.  
** 
** Program : BuildIT!
** Version : 0.2
** Authors : Artur Prusakiewicz <prusak@mat.uni.torun.pl>
**	     Michal Switala <scisly@mat.uni.torun.pl>
** E-MAIL  : build@mat.uni.torun.pl
** WWW     : http://www.mat.uni.torun.pl/~scisly/buildit/
**           http://www.mat.uni.torun.pl/~prusak/buildit/
**/

#include "Colors.h"
#include <qlabel.h>
#include <qbttngrp.h>
#include <qmlined.h>

colTab::colTab(QWidget* parent,const char* name,bool colors):QWidget( parent, name, 0 )
{
  QButtonGroup *bg1 = new QButtonGroup( this, "big" );
  bg1->setGeometry( 10, 10, 380, 280 );
  
  QButtonGroup *bg2= new QButtonGroup( this, "fonts" );
  bg2->setGeometry( 20, 80, 360, 200 );
  bg2->setTitle( "fonts" );
    
  QLabel *l= new QLabel( this, "back" );
  l->setGeometry( 20, 20, 80, 20 );
  l->setText( "background" );
  l->setAlignment( 290 );
  l->setEnabled(colors);
  
  l= new QLabel( this, "fore" );
  l->setGeometry( 20, 50, 80, 20 );
  l->setText( "foreground" );
  l->setAlignment( 290 );
  l->setEnabled(colors);

  bColor = new QPushButton( this, "bColor" );
  bColor->setGeometry( 120, 20, 70, 20 );
  bColor->setEnabled(colors);
  connect(bColor,SIGNAL(clicked()),SLOT(selectorB()));

  fColor = new QPushButton( this, "fColor" );
  fColor->setGeometry( 120, 50, 70, 20 );
  fColor->setEnabled(colors);
  connect(fColor,SIGNAL(clicked()),SLOT(selectorF()));

  
  l= new QLabel( this, "family" );
  l->setGeometry( 30, 100, 40, 20 );
  l->setText( "family" );
  l->setAlignment( 290 );
  
  Ffamily = new QComboBox(FALSE, this, "Ffamily" );
  Ffamily->setGeometry( 90, 100, 150, 20 );
  Ffamily->setSizeLimit( 12 );
  Ffamily->setAutoResize(FALSE );
  Ffamily->insertItem("arial");
  Ffamily->insertItem("charter");
  Ffamily->insertItem("courier");
  Ffamily->insertItem("fixed");
  Ffamily->insertItem("heveltica");
  Ffamily->insertItem("luicida");
  Ffamily->insertItem("mincho");
  Ffamily->insertItem("symbol");
  Ffamily->insertItem("terminal");
  Ffamily->insertItem("times");
  Ffamily->insertItem("utopia");	
  connect(Ffamily,SIGNAL(activated(const char *)),SLOT(setFamily(const char *)));
  
  l= new QLabel( this, "size" );
  l->setGeometry( 30, 130, 40, 20 );
  l->setText( "size" );
  l->setAlignment( 290 );
  
  Fsize = new QComboBox( TRUE, this, "Fsize" );
  Fsize->setGeometry( 90, 130, 60, 30 );
  Fsize->setSizeLimit( 10 );
  Fsize->setAutoResize( FALSE );
  Fsize->insertItem("");
  Fsize->insertItem("6");
  Fsize->insertItem("8");	
  Fsize->insertItem("10");	
  Fsize->insertItem("12");	
  Fsize->insertItem("14");	
  Fsize->insertItem("16");	
  Fsize->insertItem("18");	
  Fsize->insertItem("20");	
  Fsize->insertItem("22");	
  Fsize->insertItem("24");	
  Fsize->insertItem("28");
  Fsize->insertItem("30");
  Fsize->insertItem("35");
  connect(Fsize,SIGNAL(activated(const char *)),SLOT(setSize(const char *)));
  
  italic=new QCheckBox("italic",this,"italic");
  italic->setGeometry(280,100,60,20);
  connect(italic,SIGNAL(toggled(bool)),SLOT(setItItalic(bool)));
  /*
  normal=new QCheckBox("normal",this,"normal");
  normal->setGeometry(280,120,60,20);
  */
  bold=new QCheckBox("bold",this,"bold");
  bold->setGeometry(280,130,60,20);
  connect(bold,SIGNAL(toggled(bool)),SLOT(setItBold(bool)));

  tasteIt= new QMultiLineEdit( this, "MultiLineEdit_1" );
  tasteIt->setGeometry( 40, 170, 320, 90 );
  tasteIt->setReadOnly( FALSE );
  tasteIt->setOverwriteMode( FALSE );

  resize( 400,300 );
  setMinimumSize(400,300);
  setMaximumSize(400,300);
}

void colTab::setFamily(const char *val)
{
  family=new QString(val);
  sFont.setFamily(family->data());
  writeTest();
} 
void colTab::setSize(const char *val)
{
  QString *tmp=new QString(val);
  psize=tmp->toInt();
  if(psize>0)
    sFont.setPointSize(psize);
  writeTest();
}

void colTab::setItBold(bool val)
{
  sFont.setBold(val);
  writeTest();
}

void colTab::setItItalic(bool val)
{
  sFont.setItalic(val);
  writeTest();
}

void colTab::writeTest()
{
  tasteIt->setFont(sFont);
  tasteIt->setText("type something to test this font \n");
}

void colTab::setCFont(QFont val)
{
  int i;
  sFont=val;
  for(i=0;i<10;i++)
    {
      if(strcmp(Ffamily->text(i),sFont.family())==0)
	{
	  Ffamily->setCurrentItem(i);break;
	}
    }
  for(i=0;i<12;i++)
    {
      if(QString(Fsize->text(i)).toInt()==sFont.pointSize())
	{
	  Fsize->setCurrentItem(i);break;
	}
    }
  if(Fsize->currentItem()==0)
    {
      QString *temp=new QString();
      temp->setNum(sFont.pointSize());
      Fsize->changeItem(temp->data(),0);
    }

  italic->setChecked(sFont.italic());
  bold->setChecked(sFont.bold());
  writeTest();
}

void colTab::selectorB()
{
  cSel *sel=new cSel(this,"back");
  sel->setWhat(1); // background
  sel->setColor(back);
  sel->move(20,20);
  sel->show();
}
void colTab::selectorF()
{
  cSel *sel=new cSel(this,"fore");
  sel->setWhat(2); //fore
  sel->move(20,20);
  sel->setColor(fore);
  sel->show();
}

colTab::~colTab()
{
}

//selector

cSel::cSel(colTab *par,const char* name):QFrame(par,name)
{
  toChange=par;
  way=1;

  setFrameStyle(Panel | Raised);
  b1 = new colorButton( this, "1" );
  b1->setGeometry( 10, 10, 20, 20 );
  QPalette pal1(QColor(0,0,0));
  b1->setPalette(pal1);
  connect(b1,SIGNAL(cPress(QColor)),SLOT(putColor(QColor)));

  b2 = new colorButton( this, "2" );
  b2->setGeometry( 30, 10, 20, 20 );
  QPalette pal2(QColor(93,93,93));
  b2->setPalette(pal2);
  connect(b2,SIGNAL(cPress(QColor)),SLOT(putColor(QColor)));
  
  b3 = new colorButton( this, "3" );
  b3->setGeometry( 50, 10, 20, 20 );
  QPalette pal3(QColor(130,130,130));
  b3->setPalette(pal3);
  connect(b3,SIGNAL(cPress(QColor)),SLOT(putColor(QColor))); 
  
  b4 = new colorButton( this, "4" );
  b4->setGeometry( 70, 10, 20, 20 );
  QPalette pal4(QColor(170,170,170));
  b4->setPalette(pal4);
  connect(b4,SIGNAL(cPress(QColor)),SLOT(putColor(QColor))); 
  
  b5 = new colorButton( this, "5" );
  b5->setGeometry( 90, 10, 20, 20 );
  QPalette pal5(QColor(124,0,0));
  b5->setPalette(pal5);
  connect(b5,SIGNAL(cPress(QColor)),SLOT(putColor(QColor)));  
  
  b6 = new colorButton( this, "6" );
  b6->setGeometry( 110, 10, 20, 20 );
  QPalette pal6(QColor(170,0,0));
  b6->setPalette(pal6);
  connect(b6,SIGNAL(cPress(QColor)),SLOT(putColor(QColor))); 

  b7 = new colorButton( this, "7" );
  b7->setGeometry( 10, 30, 20, 20 );
  QPalette pal7(QColor(255,0,0));
  b7->setPalette(pal7);
  connect(b7,SIGNAL(cPress(QColor)),SLOT(putColor(QColor)));

  b8 = new colorButton( this, "8" );
  b8->setGeometry( 30, 30, 20, 20 );
  QPalette pal8(QColor(0,255,0));
  b8->setPalette(pal8);
  connect(b8,SIGNAL(cPress(QColor)),SLOT(putColor(QColor)));

  b9 = new colorButton( this, "9" );
  b9->setGeometry( 50, 30, 20, 20 );
  QPalette pal9(QColor(0,170,0));
  b9->setPalette(pal9);
  connect(b9,SIGNAL(cPress(QColor)),SLOT(putColor(QColor)));

  b10 = new colorButton( this, "10" );
  b10->setGeometry( 70, 30, 20, 20 );
  QPalette pal10(QColor(0,120,0));
  b10->setPalette(pal10);
  connect(b10,SIGNAL(cPress(QColor)),SLOT(putColor(QColor)));

  b11 = new colorButton( this, "11" );
  b11->setGeometry( 90, 30, 20, 20 );
  QPalette pal11(QColor(0,0,255));
  b11->setPalette(pal11);
  connect(b11,SIGNAL(cPress(QColor)),SLOT(putColor(QColor))); 

  b12 = new colorButton( this, "12" );
  b12->setGeometry( 110, 30, 20, 20 );
  QPalette pal12(QColor(0,0,180));
  b12->setPalette(pal12);  
  connect(b12,SIGNAL(cPress(QColor)),SLOT(putColor(QColor))); 

  b13 = new colorButton( this, "13" );
  b13->setGeometry( 10, 50, 20, 20 );
  QPalette pal13(QColor(0,0,140));
  b13->setPalette(pal13);
  connect(b13,SIGNAL(cPress(QColor)),SLOT(putColor(QColor))); 

  b14 = new colorButton( this, "14" );
  b14->setGeometry( 30, 50, 20, 20 );
  QPalette pal14(QColor(255,255,0));
  b14->setPalette(pal14);
  connect(b14,SIGNAL(cPress(QColor)),SLOT(putColor(QColor)));

  b15 = new colorButton( this, "15" );
  b15->setGeometry( 50, 50, 20, 20 );
  QPalette pal15(QColor(255,197,0));
  b15->setPalette(pal15);
  connect(b15,SIGNAL(cPress(QColor)),SLOT(putColor(QColor))); 

  b16 = new colorButton( this, "16" );
  b16->setGeometry( 70, 50, 20, 20 );
  QPalette pal16(QColor(255,0,255));
  b16->setPalette(pal16);  
  connect(b16,SIGNAL(cPress(QColor)),SLOT(putColor(QColor)));

  b17 = new colorButton( this, "17" );
  b17->setGeometry( 90, 50, 20, 20 );
  QPalette pal17(QColor(190,0,255));
  b17->setPalette(pal17);
  connect(b17,SIGNAL(cPress(QColor)),SLOT(putColor(QColor))); 

  b18 = new colorButton( this, "18" );
  b18->setGeometry( 110, 50, 20, 20 );
  QPalette pal18(QColor(190,0,160));
  b18->setPalette(pal18);
  connect(b18,SIGNAL(cPress(QColor)),SLOT(putColor(QColor))); 

  b19 = new colorButton( this, "19" );
  b19->setGeometry( 10, 70, 20, 20 );
  QPalette pal19(QColor(150,100,50));
  b19->setPalette(pal19);
  connect(b19,SIGNAL(cPress(QColor)),SLOT(putColor(QColor)));  

  b20 = new colorButton( this, "20" );
  b20->setGeometry( 30, 70, 20, 20 );
  QPalette pal20(QColor(180,140,100));
  b20->setPalette(pal20);
  connect(b20,SIGNAL(cPress(QColor)),SLOT(putColor(QColor))); 

  b21 = new colorButton( this, "21" );
  b21->setGeometry( 50, 70, 20, 20 );
  QPalette pal21(QColor(255,255,255));
  b21->setPalette(pal21);
  connect(b21,SIGNAL(cPress(QColor)),SLOT(putColor(QColor)));  

  more = new QPushButton( this, "more" );
  more->setGeometry( 70, 100, 60, 20 );
  more->setText( "more >>" );
  more->setAutoRepeat( FALSE );
  more->setAutoResize( FALSE );
  connect(more,SIGNAL(clicked()),SLOT(mr()));

  ok=new QPushButton(this,"ok");
  ok->setGeometry(30,134,30,20);
  ok->setText("ok");
  connect(ok,SIGNAL(clicked()),SLOT(seyOK()));
  
  csl=new QPushButton(this,"cancel");
  csl->setGeometry(80,135,50,20);
  csl->setText("cancel");
  connect(csl,SIGNAL(clicked()),SLOT(seyBye()));

  color = new QFrame( this, "color" );
  color->setGeometry( 10, 100, 50, 20 );

  rSlide = new QSlider( this, "rSlide" );
  rSlide->setGeometry( 150, 20, 100, 20 );
  rSlide->setOrientation( QSlider::Horizontal );
  rSlide->setRange( 0, 255 );
  rSlide->setSteps( 1, 10 );
  rSlide->setTracking( TRUE );
  rSlide->setTickmarks( QSlider::NoMarks );
  rSlide->setTickInterval( 0 );
  connect(rSlide,SIGNAL(sliderMoved(int)),SLOT(rSet(int)));

  gSlide = new QSlider( this, "gSlide" );
  gSlide->setGeometry( 150, 40, 100, 20 );
  gSlide->setOrientation( QSlider::Horizontal );
  gSlide->setRange( 0, 255 );
  gSlide->setSteps( 1, 10 );
  gSlide->setTracking( TRUE );
  gSlide->setTickmarks( QSlider::NoMarks );
  gSlide->setTickInterval( 0 );
  connect(gSlide,SIGNAL(sliderMoved(int)),SLOT(gSet(int)));

  bSlide = new QSlider( this, "bSlide" );
  bSlide->setGeometry( 150, 60, 100, 20 );
  bSlide->setOrientation( QSlider::Horizontal );
  bSlide->setRange( 0, 255 );
  bSlide->setSteps( 1, 10 );
  bSlide->setTracking( TRUE );
  bSlide->setTickmarks( QSlider::NoMarks );
  bSlide->setTickInterval( 0 );
  connect(bSlide,SIGNAL(sliderMoved(int)),SLOT(bSet(int)));
	
  rVal = new QLineEdit( this, "rVal" );
  rVal->setGeometry( 280, 20, 60, 20 );
  rVal->setMaxLength(3);
  connect(rVal,SIGNAL(textChanged(const char*)),SLOT(rSet(const char*)));

  gVal = new QLineEdit( this, "gVal" );
  gVal->setGeometry( 280, 40, 60, 20 );
  gVal->setMaxLength(3);  
  connect(gVal,SIGNAL(textChanged(const char*)),SLOT(gSet(const char*)));

  bVal = new QLineEdit( this, "bVal" );
  bVal->setGeometry( 280, 60, 60, 20 );
  bVal->setMaxLength(3);  
  connect(bVal,SIGNAL(textChanged(const char*)),SLOT(bSet(const char*)));

  QLabel *l= new QLabel( this, "R" );
  l->setGeometry( 250, 20, 30, 20 );
  l->setText( "R" );
  l->setAlignment( 292 );
  l->setMargin( -1 );

  l= new QLabel( this, "G" );
  l->setGeometry( 250, 40, 30, 20 );
  l->setText( "G" );
  l->setAlignment( 292 );
  l->setMargin( -1 );
  
  l=new QLabel( this, "B" );
  l->setGeometry( 250, 60, 30, 20 );
  l->setText( "B" );
  l->setAlignment( 292 );
  l->setMargin( -1 );

  
  setMaximumSize(360,160);
  setMinimumSize(140,160);
  setCaption("Colors");
  resize( 140,160 );
}

void cSel::setColor(QColor val)
{
  if(r>255)
    r=255;
  if(g>255)
    g=255;
  if(b>255)
    b=255;
  r=val.red();
  g=val.green();
  b=val.blue();
  rSlide->setValue(r);
  gSlide->setValue(g);
  bSlide->setValue(b);
  QString *tmp=new QString();
  tmp->setNum(r);rVal->setText(tmp->data());
  tmp->setNum(g);gVal->setText(tmp->data());
  tmp->setNum(b);bVal->setText(tmp->data());
  refresh();
}

void cSel::seyOK()
{
  if(what==1)
    toChange->setBack(QColor(r,g,b));
  else
    toChange->setFore(QColor(r,g,b));
  hide();
}

void cSel::seyBye()
{
  hide();
}

void cSel::mr()
{
  if(way==1)
    {
      resize(360,160);way=2;
      more->setText("more <<");
    }
  else
    {
      resize(140,160);way=1;
      more->setText("more >>");
    }
}

void cSel::rSet(int val)
{
  r=val;
  QString *tmp=new QString();
  tmp->setNum(val);
  rVal->setText(tmp->data());
  refresh();
}
void cSel::rSet(const char *val)
{
  QString *tmp=new QString(val);
  r=tmp->toInt();
  if(r>255)
    {
      r=255;
      tmp->setNum(255);
      rVal->setText(tmp->data());
    }
  if(r<0)
    {
      r=0;
      tmp->setNum(0);
      rVal->setText(tmp->data());
    }    
  rSlide->setValue(r);
  refresh();
}
void cSel::gSet(int val)
{
  g=val;
  QString *tmp=new QString();
  tmp->setNum(val);
  gVal->setText(tmp->data());
  refresh();
}
void cSel::gSet(const char *val)
{
  QString *tmp=new QString(val);
  g=tmp->toInt();
  if(g>255)
    {
      g=255;
      tmp->setNum(255);
      gVal->setText(tmp->data());
    }
  if(g<0)
    {
      g=0;
      tmp->setNum(0);
      gVal->setText(tmp->data());
    }  
  gSlide->setValue(g);
  refresh();
}
void cSel::bSet(int val)
{
  b=val;
  QString *tmp=new QString();
  tmp->setNum(val);
  bVal->setText(tmp->data());
  refresh();
}
void cSel::bSet(const char *val)
{
  QString *tmp=new QString(val);
  b=tmp->toInt();
  if(b>255)
    {
      b=255;
      tmp->setNum(255);
      bVal->setText(tmp->data());
    }
  if(b<0)
    {
      b=0;
      tmp->setNum(0);
      bVal->setText(tmp->data());
    }
  bSlide->setValue(b);
  refresh();
}
void cSel::refresh()
{
  QPalette palette(QColor(r,g,b));
  color->setPalette(palette);
}
cSel::~cSel()
{
}













































